This small module provides the means to consistently collect and process data
from Twitter's streaming API.

The authors of this module have no association with Twitter Inc., and offer no
warranty or guarantee of continued interoperability with the services offered by
Twitter Inc..

This module is licensed under a 3-clause BSD license::

    Copyright (c) 2009-2010, Robert Escriva, Rensselaer Polytechnic Institute
    All rights reserved.
    
    Redistribution and use in source and binary forms, with or without modification,
    are permitted provided that the following conditions are met:
    
        * Redistributions of source code must retain the above copyright notice,
          this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice,
          this list of conditions and the following disclaimer in the documentation
          and/or other materials provided with the distribution.
        * Neither the name of this project nor the names of its contributors
          may be used to endorse or promote products derived from this software
          without specific prior written permission.
    
    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
    ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
    ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

If you're simply looking to collect data, the quick and easy instructions are::

    $ mkdir /path/to/twitter/data
    $ cd /path/to/twitter/data
    $ twittercollect --bzip2 \
    >                --user USERNAME \
    >                --password PASSWORD \
    >                --stream-url STREAM_URL

The process does not daemonize.  It is recommended that it be run in a screen
session.  In a future release this will be changed so that it may be run as a
system daemon.

The most-available stream URL is
http://stream.twitter.com/1/statuses/sample.json.  If you have another
agreement with Twitter, substitute the provided URL here.  It is also possible
to provide the username, password, and URL using environment variables.

The public API can be summed up with just two functions.
